diff include/freeDiameter/libfdproto.h @ 1423:67c263056d78

fd_msg_search_avp: search msg_or_avp, not just msg Change fd_msg_search_avp() to support searching struct msg or struct avp, and not just struct msg.
author Luke Mewburn <luke@mewburn.net>
date Wed, 19 Feb 2020 10:20:20 +1100
parents b1e8c5281d29
children 566bb46cc73f
line wrap: on
line diff
--- a/include/freeDiameter/libfdproto.h	Wed Feb 19 10:07:17 2020 +1100
+++ b/include/freeDiameter/libfdproto.h	Wed Feb 19 10:20:20 2020 +1100
@@ -2366,12 +2366,12 @@
  * FUNCTION:	fd_msg_search_avp
  *
  * PARAMETERS:
  *  msg 	: The message structure in which to search the AVP.
  *  what 	: The dictionary model of the AVP to search.
  *  avp		: location where the AVP reference is stored if found.
  *
  * DESCRIPTION:
- *   Search the first top-level AVP of a given model inside a message.
+ *   Search for the first top-level AVP of a given model inside a message or AVP.
  * Note: only the first instance of the AVP is returned by this function.
  * Note: only top-level AVPs are searched, not inside grouped AVPs.
  * Use msg_browse if you need more advanced search features.
@@ -2381,7 +2381,7 @@
  *  EINVAL 	: A parameter is invalid.
  *  ENOENT	: No AVP has been found, and "avp" was NULL (otherwise, *avp is set to NULL and 0 returned).
  */
-int fd_msg_search_avp ( struct msg * msg, struct dict_object * what, struct avp ** avp );
+int fd_msg_search_avp ( msg_or_avp * reference, struct dict_object * what, struct avp ** avp );
 
 /*
  * FUNCTION:	fd_msg_free
@@ -2366,12 +2366,12 @@
  *
  * PARAMETERS:
- *  msg 	: The message structure in which to search the AVP.
+ *  reference 	: Pointer to a valid msg or avp in which to search the AVP.
  *  what 	: The dictionary model of the AVP to search.
  *  avp		: location where the AVP reference is stored if found.
"Welcome to our mercurial repository"